module.exports = defineTest({
	description: 'keep continue statements if their label is included'
});
